using System;
using System.Diagnostics;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using Telerik.Windows.Controls;

namespace NoRecordsGridView
{
    public class CustomRadGrid : RadGridView
    {
        public override void OnApplyTemplate()
        {
            base.OnApplyTemplate();

            this.EnsureNotRecordsTextBlock();

            var rootGrid = this.ChildrenOfType<Grid>().FirstOrDefault();

            this.noRecordText.SetValue(Grid.RowProperty, 2);
            this.noRecordText.SetValue(Grid.RowSpanProperty, 2);
            this.noRecordText.SetValue(Grid.ColumnSpanProperty, 2);

            noRecordText.Visibility = Visibility.Collapsed;
            rootGrid.Children.Add(this.noRecordText);

            ShowGroupPanel = false;
            RowIndicatorVisibility = Visibility.Collapsed;
        }

        public string NoRecordsText
        {
            get { return (string)GetValue(NoRecordsTextProperty); }
            set { SetValue(NoRecordsTextProperty, value); }
        }

        public static readonly DependencyProperty NoRecordsTextProperty =
            DependencyProperty.Register("NoRecordsText", typeof(string), typeof(CustomRadGrid), new PropertyMetadata("No records found"));



        public bool? HasNoRecords
        {
            get { return (bool?)GetValue(HasNoRecordsProperty); }
            set { SetValue(HasNoRecordsProperty, value); }
        }

        // Using a DependencyProperty as the backing store for HasNoRecords.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty HasNoRecordsProperty =
            DependencyProperty.Register("HasNoRecords", typeof(bool?), typeof(CustomRadGrid), new PropertyMetadata(OnHasNoRecordsChanged));

        private static void OnHasNoRecordsChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var source = d as CustomRadGrid;
            if (e.NewValue != null)
            {
                if ((bool)e.NewValue) source.ShowNoRecordsMessage();
            }
        }

        private TextBlock noRecordText;

        private void EnsureNotRecordsTextBlock()
        {
            if (this.noRecordText == null)
            {
                this.noRecordText = new TextBlock { Margin = new Thickness(10, 30, 10, 10), Padding = new Thickness(10), Text = NoRecordsText, FontSize = 12, VerticalAlignment = VerticalAlignment.Top, Visibility = Visibility.Visible };
            }

        }

        private void ShowNoRecordsMessage()
        {
            if (!HasNoRecords.HasValue) return;
            if (!HasNoRecords.Value) return;

            this.EnsureNotRecordsTextBlock();
            this.noRecordText.Visibility = System.Windows.Visibility.Visible;
        }

        //protected override void OnItemsSourceChanged(object oldValue, object newValue)
        //{
        //    var textBlock = _panel.Children.OfType<TextBlock>().SingleOrDefault();
        //    if(textBlock != null) _panel.Children.Remove(textBlock);
        //    base.OnItemsSourceChanged(oldValue, newValue);
        //}
    }
}